/*!
 * Copyright (c) Microsoft Corporation and contributors. All rights reserved.
 * Licensed under the MIT License.
 */
import { ITelemetryBaseLogger, IRequest } from "@fluidframework/core-interfaces";
import { ILocationRedirectionError, IUrlResolver } from "@fluidframework/driver-definitions";
/**
 * Checks if the error is location redirection error.
 * @param error - error whose type is to be determined.
 * @returns `true` is the error is location redirection error, otherwise `false`.
 */
export declare function isLocationRedirectionError(error: any): error is ILocationRedirectionError;
/**
 * Handles location redirection while fulfilling the loader request.
 * @param api - Callback in which user can wrap the loader.resolve or loader.request call.
 * @param request - request to be resolved.
 * @param urlResolver - resolver used to resolve the url.
 * @param logger - logger to send events.
 * @returns Response from the API call.
 */
export declare function resolveWithLocationRedirectionHandling<T>(api: (request: IRequest) => Promise<T>, request: IRequest, urlResolver: IUrlResolver, logger?: ITelemetryBaseLogger): Promise<T>;
//# sourceMappingURL=resolveWithLocationRedirection.d.ts.map